<TS language="nb_NO" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>Høyreklikk for å redigere adresse, eller beskrivelse</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>Opprett en ny adresse</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Ny</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Kopier den valgte adressen til utklippstavlen</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopier</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp;Lukk</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Slett den valgte adressen fra listen</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Eksporter data i den valgte fliken til en fil</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Eksport</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Slett</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>Velg en adresse å sende mynter til</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>Velg adressen som skal motta myntene</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>&amp;Velg</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>Avsender adresser</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>Mottager adresser</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>Dette er dine Bitcoin adresser for å sende  å sende betalinger. Husk å sjekke beløp og mottager adresser før du sender mynter.</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for receiving payments. It is recommended to use a new receiving address for each transaction.</source>
        <translation>Dette er dine Bitcoin adresse for å motta betalinger. Det er anbefalt å bruke en ny mottager adresse for hver transaksjon.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>&amp;Kopier adresse</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Kopier &amp;beskrivelse</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>R&amp;ediger</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>Eksporter adresse listen</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Komma separert fil (*.csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Eksporten feilet</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>Fet oppstod en feil ved lagring av adresselisten til %1. Vennligst prøv igjen.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Beskrivelse</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ingen beskrivelse)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Passord dialog</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Oppgi passord setning</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Ny passord setning</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Repeter passorsetningen</translation>
    </message>
    <message>
        <source>Enter the new passphrase to the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>Oppgi passordsetningen for lommeboken. &lt;br/&gt;Vennligst bruk en passordsetninge med &lt;b&gt;ti, eller flere tilfeldige tegn &lt;/b&gt;, eller &lt;b&gt;åtte, eller flere ord&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Krypter lommeboken</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Denne operasjonen krever passordsetningen for å låse opp lommeboken.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Lås opp lommeboken</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>Denne operasjonen krever passordsetningen for å dekryptere lommeboken.</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>Dekrypter lommeboken</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Endre passordsetningen</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase to the wallet.</source>
        <translation>Oppgi den gamle og den nye passordsetningen for lommeboken.</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Bekreft kryptering av lommeboken</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation>Advarsel: Dersom du krypterer lommeboken og mister passordsetningen vil du &lt;b&gt;MISTE ALLE DINE BITCOIN&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Er du sikker på at du vil kryptere lommeboken?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Lommeboken er kryptert</translation>
    </message>
    <message>
        <source>%1 will close now to finish the encryption process. Remember that encrypting your wallet cannot fully protect your bitcoins from being stolen by malware infecting your computer.</source>
        <translation>%1 vil nå lukkes for å fullføre krypteringsprosessen. Husk at å kryptere lommeboken ikke kan beskytte dine bitcoin fullstendig fra å bli stjålet av skadelig programvare som har infisert datamaskinen din.</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>VIKTIG: Alle tidligere sikkerhetskopier du har tatt av lommebokfilen bør erstattes med den nye krypterte lommebokfilen. Av sikkerhetsgrunner vil tidligere sikkerhetskopier av lommebokfilen bli ubrukelige når du begynner å bruke den ny kypterte lommeboken.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Kryptering av lommeboken feilet</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Lommebokkrypteringen feilet pga. en intern feil. Lommeboken din ble ikke kryptert.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>De oppgitte passordsetningene er forskjellige.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Opplåsing av lommeboken feilet</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>Passordsetningen som ble oppgitt for å dekryptere lommeboken var feil.</translation>
    </message>
    <message>
        <source>Wallet decryption failed</source>
        <translation>Dekryptering av lommeboken feilet</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>Passordsetningen for lommeboken ble endret</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Advarsel: Caps Lock er på!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation>IP/Nettmaske</translation>
    </message>
    <message>
        <source>Banned Until</source>
        <translation>Utestengt Til</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Signer &amp;melding</translation>
    </message>
    <message>
        <source>Synchronizing with network...</source>
        <translation>Synkroniserer med nettverket</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Oversikt</translation>
    </message>
    <message>
        <source>Node</source>
        <translation>Node</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Vis generell oversikt over lommeboken</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp;Transaksjoner</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Bla gjennom transaksjoner</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Avslutt</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Avslutt program</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation>&amp;Om %1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation>Vis informasjon om %1</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Om &amp;Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>Vis informasjon om Qt</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Alternativer</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation>Endre konfigurasjonsalternativer for %1</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Krypter lommebok...</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet...</source>
        <translation>&amp;Sikkerhetskopier lommebok</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;Endre passordsetning</translation>
    </message>
    <message>
        <source>&amp;Sending addresses...</source>
        <translation>&amp;Avsender adresser</translation>
    </message>
    <message>
        <source>&amp;Receiving addresses...</source>
        <translation>&amp;Mottager adresser</translation>
    </message>
    <message>
        <source>Open &amp;URI...</source>
        <translation>Åpne &amp;URI</translation>
    </message>
    <message>
        <source>Click to disable network activity.</source>
        <translation>Klikk for å slå av nettverksaktivitet.</translation>
    </message>
    <message>
        <source>Network activity disabled.</source>
        <translation>Nettverksaktivitet er slått av</translation>
    </message>
    <message>
        <source>Click to enable network activity again.</source>
        <translation>Klikk for å slå på nettverksaktivitet igjen.</translation>
    </message>
    <message>
        <source>Syncing Headers (%1%)...</source>
        <translation>Synkroniserer Headers (%1%)...</translation>
    </message>
    <message>
        <source>Reindexing blocks on disk...</source>
        <translation>Reindekserer blokker på disken</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation>Send mynter til en Bitcoin adresse</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation>Sikkerhetskopier lommeboken til en annen lokasjon</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Endre passordsetningen for kryptering av lommeboken</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>&amp;Feilsøkingsvindu</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>Åpne konsoll for feilsøking og diagnostisering</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;Verifiser meldingen...</translation>
    </message>
    <message>
        <source>Bitcoin</source>
        <translation>Bitcoin</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Lommebok</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Sende</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Motta</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>Vi&amp;s / Skjul</translation>
    </message>
    <message>
        <source>Show or hide the main Window</source>
        <translation>Vis, eller skjul, hovedvinduet</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation>Krypter de private nøklene som tilhører lommeboken din</translation>
    </message>
    <message>
        <source>Sign messages with your Bitcoin addresses to prove you own them</source>
        <translation>Signer meldingene med Bitcoin adresse for å bevise at diu eier dem</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Bitcoin addresses</source>
        <translation>Verifiser meldinger for å sikre at de ble signert med en angitt Bitcoin adresse</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fil</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>Inn&amp;stillinger</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hjelp</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation>Hjelpelinje for fliker</translation>
    </message>
    <message>
        <source>Request payments (generates QR codes and bitcoin: URIs)</source>
        <translation>Be om betalinger (genererer QR-koder og bitcoin-URIer)</translation>
    </message>
    <message>
        <source>Show the list of used sending addresses and labels</source>
        <translation>Vis lista over brukte sendeadresser og merkelapper</translation>
    </message>
    <message>
        <source>Show the list of used receiving addresses and labels</source>
        <translation>Vis lista over brukte mottakeradresser og merkelapper</translation>
    </message>
    <message>
        <source>Open a bitcoin: URI or payment request</source>
        <translation>Åpne en bitcoin: URI eller betalingsforespørsel</translation>
    </message>
    <message>
        <source>&amp;Command-line options</source>
        <translation>&amp;Kommandolinjealternativer</translation>
    </message>
    <message>
        <source>Processing blocks on disk...</source>
        <translation>Behandler blokker på disken…</translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation>%1 bak</translation>
    </message>
    <message>
        <source>Last received block was generated %1 ago.</source>
        <translation>Siste mottatte blokk ble generert for %1 siden.</translation>
    </message>
    <message>
        <source>Transactions after this will not yet be visible.</source>
        <translation>Transaksjoner etter dette vil ikke være synlige ennå.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Feilmelding</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Advarsel</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informasjon</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Oppdatert</translation>
    </message>
    <message>
        <source>Show the %1 help message to get a list with possible Bitcoin command-line options</source>
        <translation>Vis %1-hjelpemeldingen for å få en liste over mulige Bitcoin-kommandolinjealternativer</translation>
    </message>
    <message>
        <source>%1 client</source>
        <translation>%1-klient</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Tar igjen…</translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation>Dato: %1
</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation>Mengde: %1
</translation>
    </message>
    <message>
        <source>Type: %1
</source>
        <translation>Type: %1
</translation>
    </message>
    <message>
        <source>Label: %1
</source>
        <translation>Merkelapp: %1
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation>Adresse: %1
</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Sendt transaksjon</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Innkommende transaksjon</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>(no label)</source>
        <translation>(ingen beskrivelse)</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Bitcoin</source>
        <translation>Bitcoin</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Feilmelding</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Error</source>
        <translation>Feilmelding</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    </context>
<context>
    <name>QObject::QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Beskrivelse</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Label</source>
        <translation>Beskrivelse</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ingen beskrivelse)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>(no label)</source>
        <translation>(ingen beskrivelse)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>SplashScreen</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Label</source>
        <translation>Beskrivelse</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ingen beskrivelse)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Komma separert fil (*.csv)</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Beskrivelse</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Eksporten feilet</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Eksport</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Eksporter data i den valgte fliken til en fil</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Information</source>
        <translation>Informasjon</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Advarsel</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Feilmelding</translation>
    </message>
</context>
</TS>